# Generated by the protocol buffer compiler.  DO NOT EDIT!

from google.protobuf import descriptor
from google.protobuf import message
from google.protobuf import reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import locker_pb2

DESCRIPTOR = descriptor.FileDescriptor(
  name='upload.proto',
  package='',
  serialized_pb='\n\x0cupload.proto\x1a\x0clocker.proto\"\x99\x01\n\x0eResponseStatus\x12\x33\n\rresponse_code\x18\x01 \x02(\x0e\x32\x1c.ResponseStatus.ResponseCode\"R\n\x0cResponseCode\x12\x06\n\x02OK\x10\x01\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x02\x12\x0e\n\nSOFT_ERROR\x10\x03\x12\x16\n\x12METADATA_TOO_LARGE\x10\x04\"\x8f\x01\n\x0fUploadOperation\x12-\n\toperation\x18\x01 \x02(\x0e\x32\x1a.UploadOperation.Operation\"M\n\tOperation\x12\x14\n\x10OPERATION_CREATE\x10\x01\x12\x14\n\x10OPERATION_MODIFY\x10\x02\x12\x14\n\x10OPERATION_DELETE\x10\x03\"\xa5\x01\n\rChallengeInfo\x12\x17\n\x0f\x63lient_track_id\x18\x01 \x02(\t\x12\x14\n\x0cstart_millis\x18\x02 \x02(\x05\x12\x17\n\x0f\x64uration_millis\x18\x03 \x02(\x05\x12\x19\n\x11\x63hallenge_user_id\x18\x04 \x01(\t\x12\x1b\n\x13\x63hallenge_timestamp\x18\x05 \x01(\x03\x12\x14\n\x0c\x65xpect_match\x18\x06 \x01(\x08\"P\n\x13SignedChallengeInfo\x12&\n\x0e\x63hallenge_info\x18\x01 \x02(\x0b\x32\x0e.ChallengeInfo\x12\x11\n\tsignature\x18\x02 \x02(\x0c\"\xb9\x01\n\x0bTrackSample\x12\x15\n\x05track\x18\x01 \x02(\x0b\x32\x06.Track\x12\x33\n\x15signed_challenge_info\x18\x02 \x02(\x0b\x32\x14.SignedChallengeInfo\x12\x0e\n\x06sample\x18\x03 \x02(\x0c\x12)\n\rsample_format\x18\x04 \x01(\x0e\x32\x12.Track.ContentType\x12#\n\x0euser_album_art\x18\x05 \x01(\x0b\x32\x0b.ImageUnion\"u\n\x15UploadPlaylistRequest\x12*\n\x10upload_operation\x18\x01 \x02(\x0b\x32\x10.UploadOperation\x12\x1b\n\x08playlist\x18\x02 \x03(\x0b\x32\t.Playlist\x12\x13\n\x0buploader_id\x18\x03 \x02(\t\"b\n\x10PlaylistResponse\x12(\n\x0fresponse_status\x18\x01 \x02(\x0b\x32\x0f.ResponseStatus\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x11\n\tserver_id\x18\x03 \x01(\t\"F\n\x16UploadPlaylistResponse\x12,\n\x11playlist_response\x18\x01 \x03(\x0b\x32\x11.PlaylistResponse\"\x85\x01\n\x1aUploadPlaylistEntryRequest\x12*\n\x10upload_operation\x18\x01 \x02(\x0b\x32\x10.UploadOperation\x12&\n\x0eplaylist_entry\x18\x02 \x03(\x0b\x32\x0e.PlaylistEntry\x12\x13\n\x0buploader_id\x18\x03 \x02(\t\"g\n\x15PlaylistEntryResponse\x12(\n\x0fresponse_status\x18\x01 \x02(\x0b\x32\x0f.ResponseStatus\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x11\n\tserver_id\x18\x03 \x01(\t\"V\n\x1bUploadPlaylistEntryResponse\x12\x37\n\x17playlist_entry_response\x18\x01 \x03(\x0b\x32\x16.PlaylistEntryResponse\"C\n\x15UploadMetadataRequest\x12\x15\n\x05track\x18\x01 \x03(\x0b\x32\x06.Track\x12\x13\n\x0buploader_id\x18\x02 \x02(\t\"\x98\x01\n\x18UpdateUploadStateRequest\x12\x34\n\x05state\x18\x01 \x02(\x0e\x32%.UpdateUploadStateRequest.UploadState\x12\x13\n\x0buploader_id\x18\x02 \x02(\t\"1\n\x0bUploadState\x12\t\n\x05START\x10\x01\x12\n\n\x06PAUSED\x10\x02\x12\x0b\n\x07STOPPED\x10\x03\"M\n\x12\x43lientStateRequest\x12\x13\n\x0buploader_id\x18\x01 \x02(\t\x12\"\n\x1aget_purchased_tracks_since\x18\x02 \x01(\x03\"\xaf\x01\n\x13\x43lientStateResponse\x12\x1a\n\x12locker_track_limit\x18\x01 \x01(\x03\x12\x1c\n\x14user_songs_in_locker\x18\x02 \x01(\x03\x12\x1e\n\x16track_size_limit_in_mb\x18\x03 \x01(\x05\x12#\n\x1buser_purchased_tracks_since\x18\x04 \x01(\x03\x12\x19\n\x11total_track_count\x18\x05 \x01(\x03\"\x95\x01\n\x16UploadMetadataResponse\x12\x33\n\x15signed_challenge_info\x18\x01 \x03(\x0b\x32\x14.SignedChallengeInfo\x12\x11\n\tupload_id\x18\x02 \x03(\t\x12\x33\n\x15track_sample_response\x18\x03 \x03(\x0b\x32\x14.TrackSampleResponse\"\xa5\x03\n\x13TrackSampleResponse\x12\x17\n\x0f\x63lient_track_id\x18\x01 \x02(\t\x12\x38\n\rresponse_code\x18\x02 \x02(\x0e\x32!.TrackSampleResponse.ResponseCode\x12\x17\n\x0fserver_track_id\x18\x03 \x01(\t\x12\x15\n\ralbum_art_url\x18\x04 \x01(\t\x12\x14\n\x0c\x65xpect_match\x18\x05 \x01(\x08\"\xf4\x01\n\x0cResponseCode\x12\x0b\n\x07MATCHED\x10\x01\x12\x14\n\x10UPLOAD_REQUESTED\x10\x02\x12\x15\n\x11INVALID_SIGNATURE\x10\x03\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x04\x12\x13\n\x0fTRANSIENT_ERROR\x10\x05\x12\x13\n\x0fPERMANENT_ERROR\x10\x06\x12\x1d\n\x19TRACK_COUNT_LIMIT_REACHED\x10\x07\x12\x16\n\x12REJECT_STORE_TRACK\x10\x08\x12\x1f\n\x1bREJECT_STORE_TRACK_BY_LABEL\x10\t\x12\x14\n\x10REJECT_DRM_TRACK\x10\n\"N\n\x13UploadSampleRequest\x12\"\n\x0ctrack_sample\x18\x01 \x03(\x0b\x32\x0c.TrackSample\x12\x13\n\x0buploader_id\x18\x02 \x02(\t\"K\n\x14UploadSampleResponse\x12\x33\n\x15track_sample_response\x18\x01 \x03(\x0b\x32\x14.TrackSampleResponse\";\n\nImageUnion\x12\x16\n\x0euser_album_art\x18\x01 \x01(\x0c\x12\x15\n\ralbum_art_url\x18\x02 \x01(\t\"\xaf\x07\n\x0eUploadResponse\x12\x33\n\rresponse_type\x18\x01 \x01(\x0e\x32\x1c.UploadResponse.ResponseType\x12\x32\n\x11metadata_response\x18\x02 \x01(\x0b\x32\x17.UploadMetadataResponse\x12\x32\n\x11playlist_response\x18\x03 \x01(\x0b\x32\x17.UploadPlaylistResponse\x12=\n\x17playlist_entry_response\x18\x04 \x01(\x0b\x32\x1c.UploadPlaylistEntryResponse\x12.\n\x0fsample_response\x18\x05 \x01(\x0b\x32\x15.UploadSampleResponse\x12*\n\x10getjobs_response\x18\x07 \x01(\x0b\x32\x10.GetJobsResponse\x12\x32\n\x14\x63lientstate_response\x18\x08 \x01(\x0b\x32\x14.ClientStateResponse\x12\x1d\n\x06policy\x18\x06 \x01(\x0b\x32\r.ClientPolicy\x12/\n\x0b\x61uth_status\x18\x0b \x01(\x0e\x32\x1a.UploadResponse.AuthStatus\x12\x12\n\nauth_error\x18\x0c \x01(\x08\"\xfa\x01\n\x0cResponseType\x12\x15\n\x11METADATA_RESPONSE\x10\x01\x12\x15\n\x11PLAYLIST_RESPONSE\x10\x02\x12\x1b\n\x17PLAYLIST_ENTRY_RESPONSE\x10\x03\x12\x13\n\x0fSAMPLE_RESPONSE\x10\x04\x12\x14\n\x10GETJOBS_RESPONSE\x10\x05\x12\x11\n\rAUTH_RESPONSE\x10\x06\x12\x19\n\x15\x43LIENT_STATE_RESPONSE\x10\x07\x12 \n\x1cUPDATE_UPLOAD_STATE_RESPONSE\x10\x08\x12$\n DELETE_UPLOAD_REQUESTED_RESPONSE\x10\t\"\xcf\x01\n\nAuthStatus\x12\x06\n\x02OK\x10\x08\x12\x15\n\x11MAX_LIMIT_REACHED\x10\t\x12!\n\x1d\x43LIENT_BOUND_TO_OTHER_ACCOUNT\x10\n\x12\x19\n\x15\x43LIENT_NOT_AUTHORIZED\x10\x0b\x12\"\n\x1eMAX_PER_MACHINE_USERS_EXCEEDED\x10\x0c\x12\x17\n\x13\x43LIENT_PLEASE_RETRY\x10\r\x12\x12\n\x0eNOT_SUBSCRIBED\x10\x0e\x12\x13\n\x0fINVALID_REQUEST\x10\x0f\"\x9c\x01\n\x0eTracksToUpload\x12\x11\n\tclient_id\x18\x01 \x02(\t\x12\x11\n\tserver_id\x18\x02 \x02(\t\x12+\n\x06status\x18\x05 \x02(\x0e\x32\x1b.TracksToUpload.TrackStatus\"7\n\x0bTrackStatus\x12\x12\n\x0e\x46ORCE_REUPLOAD\x10\x03\x12\x14\n\x10UPLOAD_REQUESTED\x10\x04\"%\n\x0eGetJobsRequest\x12\x13\n\x0buploader_id\x18\x01 \x02(\t\"X\n\x0fGetJobsResponse\x12)\n\x10tracks_to_upload\x18\x01 \x03(\x0b\x32\x0f.TracksToUpload\x12\x1a\n\x12get_tracks_success\x18\x02 \x02(\x08\";\n\rUpAuthRequest\x12\x13\n\x0buploader_id\x18\x01 \x02(\t\x12\x15\n\rfriendly_name\x18\x02 \x01(\t\"3\n\x1c\x44\x65leteUploadRequestedRequest\x12\x13\n\x0buploader_id\x18\x01 \x02(\t\"\x83\x02\n\x0c\x43lientPolicy\x12\x15\n\rpause_uploads\x18\x01 \x01(\x08\x12\r\n\x05\x61\x62ort\x18\x02 \x01(\x08\x12\x18\n\x10retry_in_minutes\x18\x03 \x01(\x05\x12\x1a\n\x12\x62\x61ndwidth_cap_kbps\x18\x04 \x01(\x05\x12\x17\n\x0fpause_downloads\x18\x05 \x01(\x08\x12#\n\x1b\x64ownload_bandwidth_cap_kbps\x18\x06 \x01(\x05\x12\x16\n\x0esend_analytics\x18\x07 \x01(\x08\x12\x15\n\ranalytics_url\x18\x08 \x01(\t\x12\x16\n\x0e\x65nable_gapless\x18\t \x01(\x08\x12\x12\n\nenable_m4p\x18\n \x01(\x08\"X\n\x1dUploadMetadataInternalRequest\x12\x0e\n\x06gaiaid\x18\x01 \x02(\x04\x12\'\n\x07request\x18\x02 \x02(\x0b\x32\x16.UploadMetadataRequest\"\xc3\x02\n\x13OverrideConfigValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x37\n\x08priority\x18\x03 \x01(\x0e\x32%.OverrideConfigValue.OverridePriority\"\xd6\x01\n\x10OverridePriority\x12\x1d\n\x10\x44\x45\x46\x41ULT_PRIORITY\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x13\n\x0fLOWEST_PRIORITY\x10\x64\x12\x11\n\x0cLOW_PRIORITY\x10\xc8\x01\x12\x14\n\x0fMEDIUM_PRIORITY\x10\xac\x02\x12\x12\n\rHIGH_PRIORITY\x10\x90\x03\x12\x15\n\x10HIGHEST_PRIORITY\x10\xf4\x03\x12\x1c\n\x17\x44\x45\x46\x41ULT_SERVER_PRIORITY\x10\xac\x02\x12\x1c\n\x17\x44\x45\x46\x41ULT_CLIENT_PRIORITY\x10\x90\x03\"D\n\x1dOverrideConfigValueCollection\x12#\n\x05value\x18\x01 \x03(\x0b\x32\x14.OverrideConfigValue')



_RESPONSESTATUS_RESPONSECODE = descriptor.EnumDescriptor(
  name='ResponseCode',
  full_name='ResponseStatus.ResponseCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    descriptor.EnumValueDescriptor(
      name='OK', index=0, number=1,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='ALREADY_EXISTS', index=1, number=2,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='SOFT_ERROR', index=2, number=3,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='METADATA_TOO_LARGE', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=102,
  serialized_end=184,
)

_UPLOADOPERATION_OPERATION = descriptor.EnumDescriptor(
  name='Operation',
  full_name='UploadOperation.Operation',
  filename=None,
  file=DESCRIPTOR,
  values=[
    descriptor.EnumValueDescriptor(
      name='OPERATION_CREATE', index=0, number=1,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='OPERATION_MODIFY', index=1, number=2,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='OPERATION_DELETE', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=253,
  serialized_end=330,
)

_UPDATEUPLOADSTATEREQUEST_UPLOADSTATE = descriptor.EnumDescriptor(
  name='UploadState',
  full_name='UpdateUploadStateRequest.UploadState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    descriptor.EnumValueDescriptor(
      name='START', index=0, number=1,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='PAUSED', index=1, number=2,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='STOPPED', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1563,
  serialized_end=1612,
)

_TRACKSAMPLERESPONSE_RESPONSECODE = descriptor.EnumDescriptor(
  name='ResponseCode',
  full_name='TrackSampleResponse.ResponseCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    descriptor.EnumValueDescriptor(
      name='MATCHED', index=0, number=1,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='UPLOAD_REQUESTED', index=1, number=2,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='INVALID_SIGNATURE', index=2, number=3,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='ALREADY_EXISTS', index=3, number=4,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='TRANSIENT_ERROR', index=4, number=5,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='PERMANENT_ERROR', index=5, number=6,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='TRACK_COUNT_LIMIT_REACHED', index=6, number=7,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='REJECT_STORE_TRACK', index=7, number=8,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='REJECT_STORE_TRACK_BY_LABEL', index=8, number=9,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='REJECT_DRM_TRACK', index=9, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2201,
  serialized_end=2445,
)

_UPLOADRESPONSE_RESPONSETYPE = descriptor.EnumDescriptor(
  name='ResponseType',
  full_name='UploadResponse.ResponseType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    descriptor.EnumValueDescriptor(
      name='METADATA_RESPONSE', index=0, number=1,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='PLAYLIST_RESPONSE', index=1, number=2,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='PLAYLIST_ENTRY_RESPONSE', index=2, number=3,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='SAMPLE_RESPONSE', index=3, number=4,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='GETJOBS_RESPONSE', index=4, number=5,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='AUTH_RESPONSE', index=5, number=6,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='CLIENT_STATE_RESPONSE', index=6, number=7,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='UPDATE_UPLOAD_STATE_RESPONSE', index=7, number=8,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='DELETE_UPLOAD_REQUESTED_RESPONSE', index=8, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3149,
  serialized_end=3399,
)

_UPLOADRESPONSE_AUTHSTATUS = descriptor.EnumDescriptor(
  name='AuthStatus',
  full_name='UploadResponse.AuthStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    descriptor.EnumValueDescriptor(
      name='OK', index=0, number=8,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='MAX_LIMIT_REACHED', index=1, number=9,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='CLIENT_BOUND_TO_OTHER_ACCOUNT', index=2, number=10,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='CLIENT_NOT_AUTHORIZED', index=3, number=11,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='MAX_PER_MACHINE_USERS_EXCEEDED', index=4, number=12,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='CLIENT_PLEASE_RETRY', index=5, number=13,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='NOT_SUBSCRIBED', index=6, number=14,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='INVALID_REQUEST', index=7, number=15,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3402,
  serialized_end=3609,
)

_TRACKSTOUPLOAD_TRACKSTATUS = descriptor.EnumDescriptor(
  name='TrackStatus',
  full_name='TracksToUpload.TrackStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    descriptor.EnumValueDescriptor(
      name='FORCE_REUPLOAD', index=0, number=3,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='UPLOAD_REQUESTED', index=1, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3713,
  serialized_end=3768,
)

_OVERRIDECONFIGVALUE_OVERRIDEPRIORITY = descriptor.EnumDescriptor(
  name='OverridePriority',
  full_name='OverrideConfigValue.OverridePriority',
  filename=None,
  file=DESCRIPTOR,
  values=[
    descriptor.EnumValueDescriptor(
      name='DEFAULT_PRIORITY', index=0, number=-1,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='LOWEST_PRIORITY', index=1, number=100,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='LOW_PRIORITY', index=2, number=200,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='MEDIUM_PRIORITY', index=3, number=300,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='HIGH_PRIORITY', index=4, number=400,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='HIGHEST_PRIORITY', index=5, number=500,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='DEFAULT_SERVER_PRIORITY', index=6, number=300,
      options=None,
      type=None),
    descriptor.EnumValueDescriptor(
      name='DEFAULT_CLIENT_PRIORITY', index=7, number=400,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4475,
  serialized_end=4689,
)


_RESPONSESTATUS = descriptor.Descriptor(
  name='ResponseStatus',
  full_name='ResponseStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='response_code', full_name='ResponseStatus.response_code', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RESPONSESTATUS_RESPONSECODE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=31,
  serialized_end=184,
)


_UPLOADOPERATION = descriptor.Descriptor(
  name='UploadOperation',
  full_name='UploadOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='operation', full_name='UploadOperation.operation', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UPLOADOPERATION_OPERATION,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=187,
  serialized_end=330,
)


_CHALLENGEINFO = descriptor.Descriptor(
  name='ChallengeInfo',
  full_name='ChallengeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='client_track_id', full_name='ChallengeInfo.client_track_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='start_millis', full_name='ChallengeInfo.start_millis', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='duration_millis', full_name='ChallengeInfo.duration_millis', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='challenge_user_id', full_name='ChallengeInfo.challenge_user_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='challenge_timestamp', full_name='ChallengeInfo.challenge_timestamp', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='expect_match', full_name='ChallengeInfo.expect_match', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=333,
  serialized_end=498,
)


_SIGNEDCHALLENGEINFO = descriptor.Descriptor(
  name='SignedChallengeInfo',
  full_name='SignedChallengeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='challenge_info', full_name='SignedChallengeInfo.challenge_info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='signature', full_name='SignedChallengeInfo.signature', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=500,
  serialized_end=580,
)


_TRACKSAMPLE = descriptor.Descriptor(
  name='TrackSample',
  full_name='TrackSample',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='track', full_name='TrackSample.track', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='signed_challenge_info', full_name='TrackSample.signed_challenge_info', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='sample', full_name='TrackSample.sample', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='sample_format', full_name='TrackSample.sample_format', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='user_album_art', full_name='TrackSample.user_album_art', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=583,
  serialized_end=768,
)


_UPLOADPLAYLISTREQUEST = descriptor.Descriptor(
  name='UploadPlaylistRequest',
  full_name='UploadPlaylistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='upload_operation', full_name='UploadPlaylistRequest.upload_operation', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='playlist', full_name='UploadPlaylistRequest.playlist', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='uploader_id', full_name='UploadPlaylistRequest.uploader_id', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=770,
  serialized_end=887,
)


_PLAYLISTRESPONSE = descriptor.Descriptor(
  name='PlaylistResponse',
  full_name='PlaylistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='response_status', full_name='PlaylistResponse.response_status', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='client_id', full_name='PlaylistResponse.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='server_id', full_name='PlaylistResponse.server_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=889,
  serialized_end=987,
)


_UPLOADPLAYLISTRESPONSE = descriptor.Descriptor(
  name='UploadPlaylistResponse',
  full_name='UploadPlaylistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='playlist_response', full_name='UploadPlaylistResponse.playlist_response', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=989,
  serialized_end=1059,
)


_UPLOADPLAYLISTENTRYREQUEST = descriptor.Descriptor(
  name='UploadPlaylistEntryRequest',
  full_name='UploadPlaylistEntryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='upload_operation', full_name='UploadPlaylistEntryRequest.upload_operation', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='playlist_entry', full_name='UploadPlaylistEntryRequest.playlist_entry', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='uploader_id', full_name='UploadPlaylistEntryRequest.uploader_id', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1062,
  serialized_end=1195,
)


_PLAYLISTENTRYRESPONSE = descriptor.Descriptor(
  name='PlaylistEntryResponse',
  full_name='PlaylistEntryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='response_status', full_name='PlaylistEntryResponse.response_status', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='client_id', full_name='PlaylistEntryResponse.client_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='server_id', full_name='PlaylistEntryResponse.server_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1197,
  serialized_end=1300,
)


_UPLOADPLAYLISTENTRYRESPONSE = descriptor.Descriptor(
  name='UploadPlaylistEntryResponse',
  full_name='UploadPlaylistEntryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='playlist_entry_response', full_name='UploadPlaylistEntryResponse.playlist_entry_response', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1302,
  serialized_end=1388,
)


_UPLOADMETADATAREQUEST = descriptor.Descriptor(
  name='UploadMetadataRequest',
  full_name='UploadMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='track', full_name='UploadMetadataRequest.track', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='uploader_id', full_name='UploadMetadataRequest.uploader_id', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1390,
  serialized_end=1457,
)


_UPDATEUPLOADSTATEREQUEST = descriptor.Descriptor(
  name='UpdateUploadStateRequest',
  full_name='UpdateUploadStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='state', full_name='UpdateUploadStateRequest.state', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='uploader_id', full_name='UpdateUploadStateRequest.uploader_id', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UPDATEUPLOADSTATEREQUEST_UPLOADSTATE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1460,
  serialized_end=1612,
)


_CLIENTSTATEREQUEST = descriptor.Descriptor(
  name='ClientStateRequest',
  full_name='ClientStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='uploader_id', full_name='ClientStateRequest.uploader_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='get_purchased_tracks_since', full_name='ClientStateRequest.get_purchased_tracks_since', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1614,
  serialized_end=1691,
)


_CLIENTSTATERESPONSE = descriptor.Descriptor(
  name='ClientStateResponse',
  full_name='ClientStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='locker_track_limit', full_name='ClientStateResponse.locker_track_limit', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='user_songs_in_locker', full_name='ClientStateResponse.user_songs_in_locker', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='track_size_limit_in_mb', full_name='ClientStateResponse.track_size_limit_in_mb', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='user_purchased_tracks_since', full_name='ClientStateResponse.user_purchased_tracks_since', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='total_track_count', full_name='ClientStateResponse.total_track_count', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1694,
  serialized_end=1869,
)


_UPLOADMETADATARESPONSE = descriptor.Descriptor(
  name='UploadMetadataResponse',
  full_name='UploadMetadataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='signed_challenge_info', full_name='UploadMetadataResponse.signed_challenge_info', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='upload_id', full_name='UploadMetadataResponse.upload_id', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='track_sample_response', full_name='UploadMetadataResponse.track_sample_response', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=1872,
  serialized_end=2021,
)


_TRACKSAMPLERESPONSE = descriptor.Descriptor(
  name='TrackSampleResponse',
  full_name='TrackSampleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='client_track_id', full_name='TrackSampleResponse.client_track_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='response_code', full_name='TrackSampleResponse.response_code', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='server_track_id', full_name='TrackSampleResponse.server_track_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='album_art_url', full_name='TrackSampleResponse.album_art_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='expect_match', full_name='TrackSampleResponse.expect_match', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRACKSAMPLERESPONSE_RESPONSECODE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2024,
  serialized_end=2445,
)


_UPLOADSAMPLEREQUEST = descriptor.Descriptor(
  name='UploadSampleRequest',
  full_name='UploadSampleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='track_sample', full_name='UploadSampleRequest.track_sample', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='uploader_id', full_name='UploadSampleRequest.uploader_id', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2447,
  serialized_end=2525,
)


_UPLOADSAMPLERESPONSE = descriptor.Descriptor(
  name='UploadSampleResponse',
  full_name='UploadSampleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='track_sample_response', full_name='UploadSampleResponse.track_sample_response', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2527,
  serialized_end=2602,
)


_IMAGEUNION = descriptor.Descriptor(
  name='ImageUnion',
  full_name='ImageUnion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='user_album_art', full_name='ImageUnion.user_album_art', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='album_art_url', full_name='ImageUnion.album_art_url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2604,
  serialized_end=2663,
)


_UPLOADRESPONSE = descriptor.Descriptor(
  name='UploadResponse',
  full_name='UploadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='response_type', full_name='UploadResponse.response_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='metadata_response', full_name='UploadResponse.metadata_response', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='playlist_response', full_name='UploadResponse.playlist_response', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='playlist_entry_response', full_name='UploadResponse.playlist_entry_response', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='sample_response', full_name='UploadResponse.sample_response', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='getjobs_response', full_name='UploadResponse.getjobs_response', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='clientstate_response', full_name='UploadResponse.clientstate_response', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='policy', full_name='UploadResponse.policy', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='auth_status', full_name='UploadResponse.auth_status', index=8,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=8,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='auth_error', full_name='UploadResponse.auth_error', index=9,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _UPLOADRESPONSE_RESPONSETYPE,
    _UPLOADRESPONSE_AUTHSTATUS,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2666,
  serialized_end=3609,
)


_TRACKSTOUPLOAD = descriptor.Descriptor(
  name='TracksToUpload',
  full_name='TracksToUpload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='client_id', full_name='TracksToUpload.client_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='server_id', full_name='TracksToUpload.server_id', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='status', full_name='TracksToUpload.status', index=2,
      number=5, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=3,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRACKSTOUPLOAD_TRACKSTATUS,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3612,
  serialized_end=3768,
)


_GETJOBSREQUEST = descriptor.Descriptor(
  name='GetJobsRequest',
  full_name='GetJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='uploader_id', full_name='GetJobsRequest.uploader_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3770,
  serialized_end=3807,
)


_GETJOBSRESPONSE = descriptor.Descriptor(
  name='GetJobsResponse',
  full_name='GetJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='tracks_to_upload', full_name='GetJobsResponse.tracks_to_upload', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='get_tracks_success', full_name='GetJobsResponse.get_tracks_success', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3809,
  serialized_end=3897,
)


_UPAUTHREQUEST = descriptor.Descriptor(
  name='UpAuthRequest',
  full_name='UpAuthRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='uploader_id', full_name='UpAuthRequest.uploader_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='friendly_name', full_name='UpAuthRequest.friendly_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3899,
  serialized_end=3958,
)


_DELETEUPLOADREQUESTEDREQUEST = descriptor.Descriptor(
  name='DeleteUploadRequestedRequest',
  full_name='DeleteUploadRequestedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='uploader_id', full_name='DeleteUploadRequestedRequest.uploader_id', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3960,
  serialized_end=4011,
)


_CLIENTPOLICY = descriptor.Descriptor(
  name='ClientPolicy',
  full_name='ClientPolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='pause_uploads', full_name='ClientPolicy.pause_uploads', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='abort', full_name='ClientPolicy.abort', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='retry_in_minutes', full_name='ClientPolicy.retry_in_minutes', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='bandwidth_cap_kbps', full_name='ClientPolicy.bandwidth_cap_kbps', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='pause_downloads', full_name='ClientPolicy.pause_downloads', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='download_bandwidth_cap_kbps', full_name='ClientPolicy.download_bandwidth_cap_kbps', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='send_analytics', full_name='ClientPolicy.send_analytics', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='analytics_url', full_name='ClientPolicy.analytics_url', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='enable_gapless', full_name='ClientPolicy.enable_gapless', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='enable_m4p', full_name='ClientPolicy.enable_m4p', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4014,
  serialized_end=4273,
)


_UPLOADMETADATAINTERNALREQUEST = descriptor.Descriptor(
  name='UploadMetadataInternalRequest',
  full_name='UploadMetadataInternalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='gaiaid', full_name='UploadMetadataInternalRequest.gaiaid', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='request', full_name='UploadMetadataInternalRequest.request', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4275,
  serialized_end=4363,
)


_OVERRIDECONFIGVALUE = descriptor.Descriptor(
  name='OverrideConfigValue',
  full_name='OverrideConfigValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='key', full_name='OverrideConfigValue.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='value', full_name='OverrideConfigValue.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    descriptor.FieldDescriptor(
      name='priority', full_name='OverrideConfigValue.priority', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _OVERRIDECONFIGVALUE_OVERRIDEPRIORITY,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4366,
  serialized_end=4689,
)


_OVERRIDECONFIGVALUECOLLECTION = descriptor.Descriptor(
  name='OverrideConfigValueCollection',
  full_name='OverrideConfigValueCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    descriptor.FieldDescriptor(
      name='value', full_name='OverrideConfigValueCollection.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4691,
  serialized_end=4759,
)

_RESPONSESTATUS.fields_by_name['response_code'].enum_type = _RESPONSESTATUS_RESPONSECODE
_RESPONSESTATUS_RESPONSECODE.containing_type = _RESPONSESTATUS;
_UPLOADOPERATION.fields_by_name['operation'].enum_type = _UPLOADOPERATION_OPERATION
_UPLOADOPERATION_OPERATION.containing_type = _UPLOADOPERATION;
_SIGNEDCHALLENGEINFO.fields_by_name['challenge_info'].message_type = _CHALLENGEINFO
_TRACKSAMPLE.fields_by_name['track'].message_type = locker_pb2._TRACK
_TRACKSAMPLE.fields_by_name['signed_challenge_info'].message_type = _SIGNEDCHALLENGEINFO
_TRACKSAMPLE.fields_by_name['sample_format'].enum_type = locker_pb2._TRACK_CONTENTTYPE
_TRACKSAMPLE.fields_by_name['user_album_art'].message_type = _IMAGEUNION
_UPLOADPLAYLISTREQUEST.fields_by_name['upload_operation'].message_type = _UPLOADOPERATION
_UPLOADPLAYLISTREQUEST.fields_by_name['playlist'].message_type = locker_pb2._PLAYLIST
_PLAYLISTRESPONSE.fields_by_name['response_status'].message_type = _RESPONSESTATUS
_UPLOADPLAYLISTRESPONSE.fields_by_name['playlist_response'].message_type = _PLAYLISTRESPONSE
_UPLOADPLAYLISTENTRYREQUEST.fields_by_name['upload_operation'].message_type = _UPLOADOPERATION
_UPLOADPLAYLISTENTRYREQUEST.fields_by_name['playlist_entry'].message_type = locker_pb2._PLAYLISTENTRY
_PLAYLISTENTRYRESPONSE.fields_by_name['response_status'].message_type = _RESPONSESTATUS
_UPLOADPLAYLISTENTRYRESPONSE.fields_by_name['playlist_entry_response'].message_type = _PLAYLISTENTRYRESPONSE
_UPLOADMETADATAREQUEST.fields_by_name['track'].message_type = locker_pb2._TRACK
_UPDATEUPLOADSTATEREQUEST.fields_by_name['state'].enum_type = _UPDATEUPLOADSTATEREQUEST_UPLOADSTATE
_UPDATEUPLOADSTATEREQUEST_UPLOADSTATE.containing_type = _UPDATEUPLOADSTATEREQUEST;
_UPLOADMETADATARESPONSE.fields_by_name['signed_challenge_info'].message_type = _SIGNEDCHALLENGEINFO
_UPLOADMETADATARESPONSE.fields_by_name['track_sample_response'].message_type = _TRACKSAMPLERESPONSE
_TRACKSAMPLERESPONSE.fields_by_name['response_code'].enum_type = _TRACKSAMPLERESPONSE_RESPONSECODE
_TRACKSAMPLERESPONSE_RESPONSECODE.containing_type = _TRACKSAMPLERESPONSE;
_UPLOADSAMPLEREQUEST.fields_by_name['track_sample'].message_type = _TRACKSAMPLE
_UPLOADSAMPLERESPONSE.fields_by_name['track_sample_response'].message_type = _TRACKSAMPLERESPONSE
_UPLOADRESPONSE.fields_by_name['response_type'].enum_type = _UPLOADRESPONSE_RESPONSETYPE
_UPLOADRESPONSE.fields_by_name['metadata_response'].message_type = _UPLOADMETADATARESPONSE
_UPLOADRESPONSE.fields_by_name['playlist_response'].message_type = _UPLOADPLAYLISTRESPONSE
_UPLOADRESPONSE.fields_by_name['playlist_entry_response'].message_type = _UPLOADPLAYLISTENTRYRESPONSE
_UPLOADRESPONSE.fields_by_name['sample_response'].message_type = _UPLOADSAMPLERESPONSE
_UPLOADRESPONSE.fields_by_name['getjobs_response'].message_type = _GETJOBSRESPONSE
_UPLOADRESPONSE.fields_by_name['clientstate_response'].message_type = _CLIENTSTATERESPONSE
_UPLOADRESPONSE.fields_by_name['policy'].message_type = _CLIENTPOLICY
_UPLOADRESPONSE.fields_by_name['auth_status'].enum_type = _UPLOADRESPONSE_AUTHSTATUS
_UPLOADRESPONSE_RESPONSETYPE.containing_type = _UPLOADRESPONSE;
_UPLOADRESPONSE_AUTHSTATUS.containing_type = _UPLOADRESPONSE;
_TRACKSTOUPLOAD.fields_by_name['status'].enum_type = _TRACKSTOUPLOAD_TRACKSTATUS
_TRACKSTOUPLOAD_TRACKSTATUS.containing_type = _TRACKSTOUPLOAD;
_GETJOBSRESPONSE.fields_by_name['tracks_to_upload'].message_type = _TRACKSTOUPLOAD
_UPLOADMETADATAINTERNALREQUEST.fields_by_name['request'].message_type = _UPLOADMETADATAREQUEST
_OVERRIDECONFIGVALUE.fields_by_name['priority'].enum_type = _OVERRIDECONFIGVALUE_OVERRIDEPRIORITY
_OVERRIDECONFIGVALUE_OVERRIDEPRIORITY.containing_type = _OVERRIDECONFIGVALUE;
_OVERRIDECONFIGVALUECOLLECTION.fields_by_name['value'].message_type = _OVERRIDECONFIGVALUE
DESCRIPTOR.message_types_by_name['ResponseStatus'] = _RESPONSESTATUS
DESCRIPTOR.message_types_by_name['UploadOperation'] = _UPLOADOPERATION
DESCRIPTOR.message_types_by_name['ChallengeInfo'] = _CHALLENGEINFO
DESCRIPTOR.message_types_by_name['SignedChallengeInfo'] = _SIGNEDCHALLENGEINFO
DESCRIPTOR.message_types_by_name['TrackSample'] = _TRACKSAMPLE
DESCRIPTOR.message_types_by_name['UploadPlaylistRequest'] = _UPLOADPLAYLISTREQUEST
DESCRIPTOR.message_types_by_name['PlaylistResponse'] = _PLAYLISTRESPONSE
DESCRIPTOR.message_types_by_name['UploadPlaylistResponse'] = _UPLOADPLAYLISTRESPONSE
DESCRIPTOR.message_types_by_name['UploadPlaylistEntryRequest'] = _UPLOADPLAYLISTENTRYREQUEST
DESCRIPTOR.message_types_by_name['PlaylistEntryResponse'] = _PLAYLISTENTRYRESPONSE
DESCRIPTOR.message_types_by_name['UploadPlaylistEntryResponse'] = _UPLOADPLAYLISTENTRYRESPONSE
DESCRIPTOR.message_types_by_name['UploadMetadataRequest'] = _UPLOADMETADATAREQUEST
DESCRIPTOR.message_types_by_name['UpdateUploadStateRequest'] = _UPDATEUPLOADSTATEREQUEST
DESCRIPTOR.message_types_by_name['ClientStateRequest'] = _CLIENTSTATEREQUEST
DESCRIPTOR.message_types_by_name['ClientStateResponse'] = _CLIENTSTATERESPONSE
DESCRIPTOR.message_types_by_name['UploadMetadataResponse'] = _UPLOADMETADATARESPONSE
DESCRIPTOR.message_types_by_name['TrackSampleResponse'] = _TRACKSAMPLERESPONSE
DESCRIPTOR.message_types_by_name['UploadSampleRequest'] = _UPLOADSAMPLEREQUEST
DESCRIPTOR.message_types_by_name['UploadSampleResponse'] = _UPLOADSAMPLERESPONSE
DESCRIPTOR.message_types_by_name['ImageUnion'] = _IMAGEUNION
DESCRIPTOR.message_types_by_name['UploadResponse'] = _UPLOADRESPONSE
DESCRIPTOR.message_types_by_name['TracksToUpload'] = _TRACKSTOUPLOAD
DESCRIPTOR.message_types_by_name['GetJobsRequest'] = _GETJOBSREQUEST
DESCRIPTOR.message_types_by_name['GetJobsResponse'] = _GETJOBSRESPONSE
DESCRIPTOR.message_types_by_name['UpAuthRequest'] = _UPAUTHREQUEST
DESCRIPTOR.message_types_by_name['DeleteUploadRequestedRequest'] = _DELETEUPLOADREQUESTEDREQUEST
DESCRIPTOR.message_types_by_name['ClientPolicy'] = _CLIENTPOLICY
DESCRIPTOR.message_types_by_name['UploadMetadataInternalRequest'] = _UPLOADMETADATAINTERNALREQUEST
DESCRIPTOR.message_types_by_name['OverrideConfigValue'] = _OVERRIDECONFIGVALUE
DESCRIPTOR.message_types_by_name['OverrideConfigValueCollection'] = _OVERRIDECONFIGVALUECOLLECTION

class ResponseStatus(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _RESPONSESTATUS
  
  # @@protoc_insertion_point(class_scope:ResponseStatus)

class UploadOperation(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPLOADOPERATION
  
  # @@protoc_insertion_point(class_scope:UploadOperation)

class ChallengeInfo(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CHALLENGEINFO
  
  # @@protoc_insertion_point(class_scope:ChallengeInfo)

class SignedChallengeInfo(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _SIGNEDCHALLENGEINFO
  
  # @@protoc_insertion_point(class_scope:SignedChallengeInfo)

class TrackSample(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TRACKSAMPLE
  
  # @@protoc_insertion_point(class_scope:TrackSample)

class UploadPlaylistRequest(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPLOADPLAYLISTREQUEST
  
  # @@protoc_insertion_point(class_scope:UploadPlaylistRequest)

class PlaylistResponse(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PLAYLISTRESPONSE
  
  # @@protoc_insertion_point(class_scope:PlaylistResponse)

class UploadPlaylistResponse(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPLOADPLAYLISTRESPONSE
  
  # @@protoc_insertion_point(class_scope:UploadPlaylistResponse)

class UploadPlaylistEntryRequest(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPLOADPLAYLISTENTRYREQUEST
  
  # @@protoc_insertion_point(class_scope:UploadPlaylistEntryRequest)

class PlaylistEntryResponse(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PLAYLISTENTRYRESPONSE
  
  # @@protoc_insertion_point(class_scope:PlaylistEntryResponse)

class UploadPlaylistEntryResponse(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPLOADPLAYLISTENTRYRESPONSE
  
  # @@protoc_insertion_point(class_scope:UploadPlaylistEntryResponse)

class UploadMetadataRequest(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPLOADMETADATAREQUEST
  
  # @@protoc_insertion_point(class_scope:UploadMetadataRequest)

class UpdateUploadStateRequest(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPDATEUPLOADSTATEREQUEST
  
  # @@protoc_insertion_point(class_scope:UpdateUploadStateRequest)

class ClientStateRequest(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CLIENTSTATEREQUEST
  
  # @@protoc_insertion_point(class_scope:ClientStateRequest)

class ClientStateResponse(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CLIENTSTATERESPONSE
  
  # @@protoc_insertion_point(class_scope:ClientStateResponse)

class UploadMetadataResponse(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPLOADMETADATARESPONSE
  
  # @@protoc_insertion_point(class_scope:UploadMetadataResponse)

class TrackSampleResponse(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TRACKSAMPLERESPONSE
  
  # @@protoc_insertion_point(class_scope:TrackSampleResponse)

class UploadSampleRequest(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPLOADSAMPLEREQUEST
  
  # @@protoc_insertion_point(class_scope:UploadSampleRequest)

class UploadSampleResponse(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPLOADSAMPLERESPONSE
  
  # @@protoc_insertion_point(class_scope:UploadSampleResponse)

class ImageUnion(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _IMAGEUNION
  
  # @@protoc_insertion_point(class_scope:ImageUnion)

class UploadResponse(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPLOADRESPONSE
  
  # @@protoc_insertion_point(class_scope:UploadResponse)

class TracksToUpload(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TRACKSTOUPLOAD
  
  # @@protoc_insertion_point(class_scope:TracksToUpload)

class GetJobsRequest(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _GETJOBSREQUEST
  
  # @@protoc_insertion_point(class_scope:GetJobsRequest)

class GetJobsResponse(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _GETJOBSRESPONSE
  
  # @@protoc_insertion_point(class_scope:GetJobsResponse)

class UpAuthRequest(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPAUTHREQUEST
  
  # @@protoc_insertion_point(class_scope:UpAuthRequest)

class DeleteUploadRequestedRequest(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _DELETEUPLOADREQUESTEDREQUEST
  
  # @@protoc_insertion_point(class_scope:DeleteUploadRequestedRequest)

class ClientPolicy(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CLIENTPOLICY
  
  # @@protoc_insertion_point(class_scope:ClientPolicy)

class UploadMetadataInternalRequest(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _UPLOADMETADATAINTERNALREQUEST
  
  # @@protoc_insertion_point(class_scope:UploadMetadataInternalRequest)

class OverrideConfigValue(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _OVERRIDECONFIGVALUE
  
  # @@protoc_insertion_point(class_scope:OverrideConfigValue)

class OverrideConfigValueCollection(message.Message):
  __metaclass__ = reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _OVERRIDECONFIGVALUECOLLECTION
  
  # @@protoc_insertion_point(class_scope:OverrideConfigValueCollection)

# @@protoc_insertion_point(module_scope)
